@@ -799,6 +799,30 @@ class Agent(Insight, Channel, Catalog, Dataset):
 
         return response.json()
 
+    def get_card_slug_from_feed(self, feed_slug):
+
+        channel_id = self.get_channel(feed_slug)
+
+        url = self._base_url_ch+"/"+channel_id+"/feed?page=0&limit=100&agentId="+self._agentId
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {"Authorization": "Bearer" + " " + self._token}
+        response = s.get(url=url, headers=headers)
+        response.raise_for_status()
+        cards = response.json()
+
+        slugs = []
+
+        for card in cards:
+            if card["id"] is not "_system-highlight":
+                slugs.append(card["insightSlug"])
+
+        return slugs
+
 
     def get_dataset_slug_from_id(self, dataset_id: str) -> str:
         """
